summaryrefslogtreecommitdiff
path: root/board/banshee/fw_config.h
diff options
context:
space:
mode:
authorLogan_Liao <logan_Liao@compal.corp-partner.google.com>2022-01-26 17:58:18 +0800
committerCommit Bot <commit-bot@chromium.org>2022-02-10 17:19:24 +0000
commit4f1a1e2dab152e2a360d42979a8371baf66d9644 (patch)
treee4941ab1f4975247912d0e05e405e0625300ff9d /board/banshee/fw_config.h
parent6c55b9f02cbe56909a62456f207661db46a3dfe1 (diff)
downloadchrome-ec-4f1a1e2dab152e2a360d42979a8371baf66d9644.tar.gz
Banshee : GPIO Initial & modify type-c ports.
This patch base on circuit initial GPIO, and then add the fourth type-c port and modify the other three ports setting for banshee. BUG=b:214871796 BRANCH=brya TEST=make BOARD=banshee success Change-Id: I12a19191e364394293cfd28693341177014861d6 Signed-off-by: Logan_Liao <logan_Liao@compal.corp-partner.google.com> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/3412628 Reviewed-by: Elthan Huang <elthan_huang@compal.corp-partner.google.com> Reviewed-by: Boris Mittelberg <bmbm@google.com> Tested-by: Matt Wang <matt_wang@compal.corp-partner.google.com> Reviewed-by: Logan Liao <logan_liao@compal.corp-partner.google.com> Commit-Queue: Logan Liao <logan_liao@compal.corp-partner.google.com> Tested-by: Logan Liao <logan_liao@compal.corp-partner.google.com>
Diffstat (limited to 'board/banshee/fw_config.h')
-rw-r--r--board/banshee/fw_config.h19
1 files changed, 3 insertions, 16 deletions
diff --git a/board/banshee/fw_config.h b/board/banshee/fw_config.h
index ed4dbce7d9..6800c492ad 100644
--- a/board/banshee/fw_config.h
+++ b/board/banshee/fw_config.h
@@ -9,25 +9,19 @@
#include <stdint.h>
/****************************************************************************
* CBI FW_CONFIG layout for Brya board.
*
* Source of truth is the project/brya/brya/config.star configuration file.
*/
-enum ec_cfg_usb_db_type {
- DB_USB_ABSENT = 0,
- DB_USB3_PS8815 = 1,
- DB_USB_ABSENT2 = 15
-};
enum ec_cfg_keyboard_backlight_type {
KEYBOARD_BACKLIGHT_DISABLED = 0,
KEYBOARD_BACKLIGHT_ENABLED = 1
};
-union brya_cbi_fw_config {
+union banshee_cbi_fw_config {
struct {
- enum ec_cfg_usb_db_type usb_db : 4;
uint32_t sd_db : 2;
uint32_t lte_db : 1;
enum ec_cfg_keyboard_backlight_type kb_bl : 1;
@@ -42,13 +36,6 @@ union brya_cbi_fw_config {
*
* @return the FW_CONFIG for the board.
*/
-union brya_cbi_fw_config get_fw_config(void);
-
-/**
- * Get the USB daughter board type from FW_CONFIG.
- *
- * @return the USB daughter board type.
- */
-enum ec_cfg_usb_db_type ec_cfg_usb_db_type(void);
+union banshee_cbi_fw_config get_fw_config(void);
#endif /* __BOARD_BRYA_FW_CONFIG_H_ */
@@ -9,25 +9,19 @@
#include <stdint.h>
/****************************************************************************
- * CBI FW_CONFIG layout for Brya board.
+ * CBI FW_CONFIG layout for Banshee board.
*
* Source of truth is the project/brya/brya/config.star configuration file.